pub enum BinaryOp {
Show 21 variants
Add,
Subtract,
Multiply,
Divide,
Modulo,
Equal,
NotEqual,
LessThan,
LessThanOrEqual,
GreaterThan,
GreaterThanOrEqual,
And,
Or,
Xor,
Concat,
In,
NotIn,
StartsWith,
EndsWith,
Contains,
Like,
}Variants
Add
Subtract
Multiply
Divide
Modulo
Equal
NotEqual
LessThan
LessThanOrEqual
GreaterThan
GreaterThanOrEqual
And
Or
Xor
Concat
In
x IN [list] — true if x equals any element of the list
NotIn
x NOT IN [list] — true if x equals no element of the list
StartsWith
x STARTS WITH prefix — true if string x starts with prefix
EndsWith
x ENDS WITH suffix — true if string x ends with suffix
Contains
x CONTAINS substr — true if string x contains substr
Like
x LIKE pattern — true if string x matches the SQL LIKE pattern